# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/domo_library',
                'doc_host': 'https://jaewilson07.github.io',
                'git_url': 'https://github.com/jaewilson07/domo_library',
                'lib_path': 'domolibrary'},
  'syms': { 'domolibrary.classes.DomoAccount': { 'domolibrary.classes.DomoAccount.AccountConfig': ( 'classes/domoaccount.html#accountconfig',
                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount': ( 'classes/domoaccount.html#domoaccount',
                                                                                                  'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount._from_json': ( 'classes/domoaccount.html#domoaccount._from_json',
                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount._get_config': ( 'classes/domoaccount.html#domoaccount._get_config',
                                                                                                              'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.create_account': ( 'classes/domoaccount.html#domoaccount.create_account',
                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.delete_account': ( 'classes/domoaccount.html#domoaccount.delete_account',
                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.generate_create_body': ( 'classes/domoaccount.html#domoaccount.generate_create_body',
                                                                                                                       'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.get_from_id': ( 'classes/domoaccount.html#domoaccount.get_from_id',
                                                                                                              'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.update_config': ( 'classes/domoaccount.html#domoaccount.update_config',
                                                                                                                'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.update_name': ( 'classes/domoaccount.html#domoaccount.update_name',
                                                                                                              'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config': ( 'classes/domoaccount.html#domoaccount_config',
                                                                                                         'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config._from_json': ( 'classes/domoaccount.html#domoaccount_config._from_json',
                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config.to_json': ( 'classes/domoaccount.html#domoaccount_config.to_json',
                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AbstractCredential': ( 'classes/domoaccount.html#domoaccount_config_abstractcredential',
                                                                                                                            'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AbstractCredential.__post_init_': ( 'classes/domoaccount.html#domoaccount_config_abstractcredential.__post_init_',
                                                                                                                                         'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AbstractCredential._from_json': ( 'classes/domoaccount.html#domoaccount_config_abstractcredential._from_json',
                                                                                                                                       'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AbstractCredential.to_json': ( 'classes/domoaccount.html#domoaccount_config_abstractcredential.to_json',
                                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DatasetCopy': ( 'classes/domoaccount.html#domoaccount_config_datasetcopy',
                                                                                                                     'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DatasetCopy.__post_init_': ( 'classes/domoaccount.html#domoaccount_config_datasetcopy.__post_init_',
                                                                                                                                  'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DatasetCopy._from_json': ( 'classes/domoaccount.html#domoaccount_config_datasetcopy._from_json',
                                                                                                                                'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DatasetCopy.to_json': ( 'classes/domoaccount.html#domoaccount_config_datasetcopy.to_json',
                                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_Governance': ( 'classes/domoaccount.html#domoaccount_config_governance',
                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_Governance.__post_init_': ( 'classes/domoaccount.html#domoaccount_config_governance.__post_init_',
                                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_Governance._from_json': ( 'classes/domoaccount.html#domoaccount_config_governance._from_json',
                                                                                                                               'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_Governance.to_json': ( 'classes/domoaccount.html#domoaccount_config_governance.to_json',
                                                                                                                            'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_HighBandwidthConnector': ( 'classes/domoaccount.html#domoaccount_config_highbandwidthconnector',
                                                                                                                                'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_HighBandwidthConnector.__post_init_': ( 'classes/domoaccount.html#domoaccount_config_highbandwidthconnector.__post_init_',
                                                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_HighBandwidthConnector._from_json': ( 'classes/domoaccount.html#domoaccount_config_highbandwidthconnector._from_json',
                                                                                                                                           'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_HighBandwidthConnector.to_json': ( 'classes/domoaccount.html#domoaccount_config_highbandwidthconnector.to_json',
                                                                                                                                        'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_CreateAccount_Error': ( 'classes/domoaccount.html#domoaccount_createaccount_error',
                                                                                                                      'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_CreateAccount_Error.__init__': ( 'classes/domoaccount.html#domoaccount_createaccount_error.__init__',
                                                                                                                               'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_DeleteAccount_Error': ( 'classes/domoaccount.html#domoaccount_deleteaccount_error',
                                                                                                                      'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_DeleteAccount_Error.__init__': ( 'classes/domoaccount.html#domoaccount_deleteaccount_error.__init__',
                                                                                                                               'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_UpdateName_Error': ( 'classes/domoaccount.html#domoaccount_updatename_error',
                                                                                                                   'domolibrary/classes/DomoAccount.py')},
            'domolibrary.classes.DomoActivityLog': { 'domolibrary.classes.DomoActivityLog.ActivityLog_ObjectType': ( 'classes/domoactivitylog.html#activitylog_objecttype',
                                                                                                                     'domolibrary/classes/DomoActivityLog.py'),
                                                     'domolibrary.classes.DomoActivityLog.DomoActivityLog': ( 'classes/domoactivitylog.html#domoactivitylog',
                                                                                                              'domolibrary/classes/DomoActivityLog.py'),
                                                     'domolibrary.classes.DomoActivityLog.DomoActivityLog._process_activity_log_row': ( 'classes/domoactivitylog.html#domoactivitylog._process_activity_log_row',
                                                                                                                                        'domolibrary/classes/DomoActivityLog.py'),
                                                     'domolibrary.classes.DomoActivityLog.DomoActivityLog.get_activity_log': ( 'classes/domoactivitylog.html#domoactivitylog.get_activity_log',
                                                                                                                               'domolibrary/classes/DomoActivityLog.py')},
            'domolibrary.classes.DomoBootstrap': { 'domolibrary.classes.DomoBootstrap.DomoBootstrap': ( 'classes/.domobootstrap.html#domobootstrap',
                                                                                                        'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap.get_all': ( 'classes/.domobootstrap.html#domobootstrap.get_all',
                                                                                                                'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap.get_features': ( 'classes/.domobootstrap.html#domobootstrap.get_features',
                                                                                                                     'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap.get_pages': ( 'classes/.domobootstrap.html#domobootstrap.get_pages',
                                                                                                                  'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap_Feature': ( 'classes/.domobootstrap.html#domobootstrap_feature',
                                                                                                                'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap_Feature._from_json_bootstrap': ( 'classes/.domobootstrap.html#domobootstrap_feature._from_json_bootstrap',
                                                                                                                                     'domolibrary/classes/DomoBootstrap.py')},
            'domolibrary.classes.DomoDataset': { 'domolibrary.classes.DomoDataset.DatasetSchema_AuthNotProvidedError': ( 'classes/domodataset.html#datasetschema_authnotprovidederror',
                                                                                                                         'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetSchema_AuthNotProvidedError.__init__': ( 'classes/domodataset.html#datasetschema_authnotprovidederror.__init__',
                                                                                                                                  'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetSchema_DatasetNotProvidedError': ( 'classes/domodataset.html#datasetschema_datasetnotprovidederror',
                                                                                                                            'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetSchema_DatasetNotProvidedError.__init__': ( 'classes/domodataset.html#datasetschema_datasetnotprovidederror.__init__',
                                                                                                                                     'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetSchema_Types': ( 'classes/domodataset.html#datasetschema_types',
                                                                                                          'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetTags_AuthNotProvidedError': ( 'classes/domodataset.html#datasettags_authnotprovidederror',
                                                                                                                       'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetTags_AuthNotProvidedError.__init__': ( 'classes/domodataset.html#datasettags_authnotprovidederror.__init__',
                                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetTags_SetTagsError': ( 'classes/domodataset.html#datasettags_settagserror',
                                                                                                               'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetTags_SetTagsError.__init__': ( 'classes/domodataset.html#datasettags_settagserror.__init__',
                                                                                                                        'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset': ( 'classes/domodataset.html#domodataset',
                                                                                                  'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.__post_init__': ( 'classes/domodataset.html#domodataset.__post_init__',
                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.create': ( 'classes/domodataset.html#domodataset.create',
                                                                                                         'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.delete': ( 'classes/domodataset.html#domodataset.delete',
                                                                                                         'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.display_url': ( 'classes/domodataset.html#domodataset.display_url',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.get_from_id': ( 'classes/domodataset.html#domodataset.get_from_id',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.index_dataset': ( 'classes/domodataset.html#domodataset.index_dataset',
                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.list_partitions': ( 'classes/domodataset.html#domodataset.list_partitions',
                                                                                                                  'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.query_dataset_private': ( 'classes/domodataset.html#domodataset.query_dataset_private',
                                                                                                                        'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.upload_data': ( 'classes/domodataset.html#domodataset.upload_data',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_CreateDataset_Error': ( 'classes/domodataset.html#domodataset_createdataset_error',
                                                                                                                      'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_CreateDataset_Error.__init__': ( 'classes/domodataset.html#domodataset_createdataset_error.__init__',
                                                                                                                               'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_DeleteDataset_Error': ( 'classes/domodataset.html#domodataset_deletedataset_error',
                                                                                                                      'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_DeleteDataset_Error.__init__': ( 'classes/domodataset.html#domodataset_deletedataset_error.__init__',
                                                                                                                               'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema': ( 'classes/domodataset.html#domodataset_schema',
                                                                                                         'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema.get': ( 'classes/domodataset.html#domodataset_schema.get',
                                                                                                             'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema_Column': ( 'classes/domodataset.html#domodataset_schema_column',
                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema_Column._from_json': ( 'classes/domodataset.html#domodataset_schema_column._from_json',
                                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags': ( 'classes/domodataset.html#domodataset_tags',
                                                                                                       'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags._have_prereqs': ( 'classes/domodataset.html#domodataset_tags._have_prereqs',
                                                                                                                     'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.add': ( 'classes/domodataset.html#domodataset_tags.add',
                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.get': ( 'classes/domodataset.html#domodataset_tags.get',
                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.remove': ( 'classes/domodataset.html#domodataset_tags.remove',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.set': ( 'classes/domodataset.html#domodataset_tags.set',
                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_UploadData_DatasetUploadId_Error': ( 'classes/domodataset.html#domodataset_uploaddata_datasetuploadid_error',
                                                                                                                                   'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_UploadData_DatasetUploadId_Error.__init__': ( 'classes/domodataset.html#domodataset_uploaddata_datasetuploadid_error.__init__',
                                                                                                                                            'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_UploadData_Error': ( 'classes/domodataset.html#domodataset_uploaddata_error',
                                                                                                                   'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_UploadData_Error.__init__': ( 'classes/domodataset.html#domodataset_uploaddata_error.__init__',
                                                                                                                            'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_UploadData_UploadData_Error': ( 'classes/domodataset.html#domodataset_uploaddata_uploaddata_error',
                                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_UploadData_UploadData_Error.DomoDataset_UploadData_CommitDatasetUploadId_Error': ( 'classes/domodataset.html#domodataset_uploaddata_uploaddata_error.domodataset_uploaddata_commitdatasetuploadid_error',
                                                                                                                                                                                 'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_UploadData_UploadData_Error.__init__': ( 'classes/domodataset.html#domodataset_uploaddata_uploaddata_error.__init__',
                                                                                                                                       'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.QueryExecutionError': ( 'classes/domodataset.html#queryexecutionerror',
                                                                                                          'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.QueryExecutionError.__init__': ( 'classes/domodataset.html#queryexecutionerror.__init__',
                                                                                                                   'domolibrary/classes/DomoDataset.py')},
            'domolibrary.classes.DomoPage': { 'domolibrary.classes.DomoPage.DomoPage': ( 'classes/domopage.html#domopage',
                                                                                         'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage._from_bootstrap': ( 'classes/domopage.html#domopage._from_bootstrap',
                                                                                                         'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.display_url': ( 'classes/domopage.html#domopage.display_url',
                                                                                                     'domolibrary/classes/DomoPage.py')},
            'domolibrary.classes.DomoUser': { 'domolibrary.classes.DomoUser.DomoUser': ( 'classes/domouser.html#domouser',
                                                                                         'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser._from_bootstrap_json': ( 'classes/domouser.html#domouser._from_bootstrap_json',
                                                                                                              'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser._from_search_json': ( 'classes/domouser.html#domouser._from_search_json',
                                                                                                           'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser._from_virtual_json': ( 'classes/domouser.html#domouser._from_virtual_json',
                                                                                                            'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.create_user': ( 'classes/domouser.html#domouser.create_user',
                                                                                                     'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.request_password_reset': ( 'classes/domouser.html#domouser.request_password_reset',
                                                                                                                'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.reset_password': ( 'classes/domouser.html#domouser.reset_password',
                                                                                                        'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.set_user_landing_page': ( 'classes/domouser.html#domouser.set_user_landing_page',
                                                                                                               'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers': ( 'classes/domouser.html#domousers',
                                                                                          'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers._generate_logger': ( 'classes/domouser.html#domousers._generate_logger',
                                                                                                           'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers._users_to_domo_user': ( 'classes/domouser.html#domousers._users_to_domo_user',
                                                                                                              'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers._users_to_virtual_user': ( 'classes/domouser.html#domousers._users_to_virtual_user',
                                                                                                                 'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.all_users': ( 'classes/domouser.html#domousers.all_users',
                                                                                                    'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.by_email': ( 'classes/domouser.html#domousers.by_email',
                                                                                                   'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.by_id': ( 'classes/domouser.html#domousers.by_id',
                                                                                                'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.util_match_domo_users_to_emails': ( 'classes/domouser.html#domousers.util_match_domo_users_to_emails',
                                                                                                                          'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.util_match_users_obj_to_emails': ( 'classes/domouser.html#domousers.util_match_users_obj_to_emails',
                                                                                                                         'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.virtual_user_by_subscriber_instance': ( 'classes/domouser.html#domousers.virtual_user_by_subscriber_instance',
                                                                                                                              'domolibrary/classes/DomoUser.py')},
            'domolibrary.client.DomoAuth': { 'domolibrary.client.DomoAuth.DomoAuth': ( 'client/domoauth.html#domoauth',
                                                                                       'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth': ( 'client/domoauth.html#domodeveloperauth',
                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth.__init__': ( 'client/domoauth.html#domodeveloperauth.__init__',
                                                                                                         'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth.generate_auth_header': ( 'client/domoauth.html#domodeveloperauth.generate_auth_header',
                                                                                                                     'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth.get_auth_token': ( 'client/domoauth.html#domodeveloperauth.get_auth_token',
                                                                                                               'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoErrror': ( 'client/domoauth.html#domoerrror',
                                                                                         'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoErrror.__init__': ( 'client/domoauth.html#domoerrror.__init__',
                                                                                                  'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoFullAuth': ( 'client/domoauth.html#domofullauth',
                                                                                           'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoFullAuth.generate_auth_header': ( 'client/domoauth.html#domofullauth.generate_auth_header',
                                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoFullAuth.get_auth_token': ( 'client/domoauth.html#domofullauth.get_auth_token',
                                                                                                          'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoTokenAuth': ( 'client/domoauth.html#domotokenauth',
                                                                                            'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoTokenAuth.generate_auth_header': ( 'client/domoauth.html#domotokenauth.generate_auth_header',
                                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoTokenAuth.get_auth_token': ( 'client/domoauth.html#domotokenauth.get_auth_token',
                                                                                                           'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidCredentialsError': ( 'client/domoauth.html#invalidcredentialserror',
                                                                                                      'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidCredentialsError.__init__': ( 'client/domoauth.html#invalidcredentialserror.__init__',
                                                                                                               'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidInstanceError': ( 'client/domoauth.html#invalidinstanceerror',
                                                                                                   'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidInstanceError.__init__': ( 'client/domoauth.html#invalidinstanceerror.__init__',
                                                                                                            'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional': ( 'client/domoauth.html#_domoauth_optional',
                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional.generate_auth_header': ( 'client/domoauth.html#_domoauth_optional.generate_auth_header',
                                                                                                                      'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional.get_auth_token': ( 'client/domoauth.html#_domoauth_optional.get_auth_token',
                                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional.print_is_token': ( 'client/domoauth.html#_domoauth_optional.print_is_token',
                                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Required': ( 'client/domoauth.html#_domoauth_required',
                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Required.__post_init__': ( 'client/domoauth.html#_domoauth_required.__post_init__',
                                                                                                               'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Required.set_manual_login': ( 'client/domoauth.html#_domoauth_required.set_manual_login',
                                                                                                                  'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoDeveloperAuth_Required': ( 'client/domoauth.html#_domodeveloperauth_required',
                                                                                                          'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoFullAuth_Required': ( 'client/domoauth.html#_domofullauth_required',
                                                                                                     'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoTokenAuth_Required': ( 'client/domoauth.html#_domotokenauth_required',
                                                                                                      'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.get_developer_auth': ( 'client/domoauth.html#get_developer_auth',
                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.get_full_auth': ( 'client/domoauth.html#get_full_auth',
                                                                                            'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.test_access_token': ( 'client/domoauth.html#test_access_token',
                                                                                                'domolibrary/client/DomoAuth.py')},
            'domolibrary.client.Logger': { 'domolibrary.client.Logger.Logger': ( 'client/logger.html#logger',
                                                                                 'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.__init__': ( 'client/logger.html#logger.__init__',
                                                                                          'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._add_crumb': ( 'client/logger.html#logger._add_crumb',
                                                                                            'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._add_log': ( 'client/logger.html#logger._add_log',
                                                                                          'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._get_traceback': ( 'client/logger.html#logger._get_traceback',
                                                                                                'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._get_traceback_details': ( 'client/logger.html#logger._get_traceback_details',
                                                                                                        'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._remove_crumb': ( 'client/logger.html#logger._remove_crumb',
                                                                                               'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.log_error': ( 'client/logger.html#logger.log_error',
                                                                                           'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.log_info': ( 'client/logger.html#logger.log_info',
                                                                                          'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.log_warning': ( 'client/logger.html#logger.log_warning',
                                                                                             'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.output_log': ( 'client/logger.html#logger.output_log',
                                                                                            'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.TracebackDetails': ( 'client/logger.html#tracebackdetails',
                                                                                           'domolibrary/client/Logger.py')},
            'domolibrary.client.ResponseGetData': { 'domolibrary.client.ResponseGetData.ResponseGetData': ( 'client/responsegetdata.html#responsegetdata',
                                                                                                            'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_aiohttp_response': ( 'client/responsegetdata.html#responsegetdata._from_aiohttp_response',
                                                                                                                                   'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_httpx_response': ( 'client/responsegetdata.html#responsegetdata._from_httpx_response',
                                                                                                                                 'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_looper': ( 'client/responsegetdata.html#responsegetdata._from_looper',
                                                                                                                         'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_requests_response': ( 'client/responsegetdata.html#responsegetdata._from_requests_response',
                                                                                                                                    'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData.set_response': ( 'client/responsegetdata.html#responsegetdata.set_response',
                                                                                                                         'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData._read_stream': ( 'client/responsegetdata.html#_read_stream',
                                                                                                         'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData._write_stream': ( 'client/responsegetdata.html#_write_stream',
                                                                                                          'domolibrary/client/ResponseGetData.py')},
            'domolibrary.client.get_data': { 'domolibrary.client.get_data.LooperError': ( 'client/get_data.html#loopererror',
                                                                                          'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.LooperError.__init__': ( 'client/get_data.html#loopererror.__init__',
                                                                                                   'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.get_data': ( 'client/get_data.html#get_data',
                                                                                       'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.get_data_aiohttp': ( 'client/get_data.html#get_data_aiohttp',
                                                                                               'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.looper': ( 'client/get_data.html#looper',
                                                                                     'domolibrary/client/get_data.py')},
            'domolibrary.integrations.DomoJupyter': { 'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth': ( 'integrations/domojupyter.html#dojoaccount_instanceauth',
                                                                                                                         'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth.__post_init__': ( 'integrations/domojupyter.html#dojoaccount_instanceauth.__post_init__',
                                                                                                                                       'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth._clean_account_admin_accounts': ( 'integrations/domojupyter.html#dojoaccount_instanceauth._clean_account_admin_accounts',
                                                                                                                                                       'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth._generate_auth': ( 'integrations/domojupyter.html#dojoaccount_instanceauth._generate_auth',
                                                                                                                                        'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth._set_display_name': ( 'integrations/domojupyter.html#dojoaccount_instanceauth._set_display_name',
                                                                                                                                           'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth._test_regex_mask': ( 'integrations/domojupyter.html#dojoaccount_instanceauth._test_regex_mask',
                                                                                                                                          'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth.generate_auth_ls': ( 'integrations/domojupyter.html#dojoaccount_instanceauth.generate_auth_ls',
                                                                                                                                          'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DojoAccount_InstanceAuth.get_domo_instance_auth_account': ( 'integrations/domojupyter.html#dojoaccount_instanceauth.get_domo_instance_auth_account',
                                                                                                                                                        'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_CredentialsNotProvided': ( 'integrations/domojupyter.html#generateauth_credentialsnotprovided',
                                                                                                                                    'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_CredentialsNotProvided.__init__': ( 'integrations/domojupyter.html#generateauth_credentialsnotprovided.__init__',
                                                                                                                                             'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_InvalidDomoInstanceList': ( 'integrations/domojupyter.html#generateauth_invaliddomoinstancelist',
                                                                                                                                     'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_InvalidDomoInstanceList.__init__': ( 'integrations/domojupyter.html#generateauth_invaliddomoinstancelist.__init__',
                                                                                                                                              'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetDomains_Query_AuthMatch_Error': ( 'integrations/domojupyter.html#getdomains_query_authmatch_error',
                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetDomains_Query_AuthMatch_Error.__init__': ( 'integrations/domojupyter.html#getdomains_query_authmatch_error.__init__',
                                                                                                                                          'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetDomains_Query_Exception_PW_Col_Error': ( 'integrations/domojupyter.html#getdomains_query_exception_pw_col_error',
                                                                                                                                        'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetDomains_Query_Exception_PW_Col_Error.__init__': ( 'integrations/domojupyter.html#getdomains_query_exception_pw_col_error.__init__',
                                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig': ( 'integrations/domojupyter.html#getinstanceconfig',
                                                                                                                  'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig.__init__': ( 'integrations/domojupyter.html#getinstanceconfig.__init__',
                                                                                                                           'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig._retrieve_company_ds': ( 'integrations/domojupyter.html#getinstanceconfig._retrieve_company_ds',
                                                                                                                                       'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig.get_domains_with_global_config_auth': ( 'integrations/domojupyter.html#getinstanceconfig.get_domains_with_global_config_auth',
                                                                                                                                                      'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig.get_domains_with_instance_auth': ( 'integrations/domojupyter.html#getinstanceconfig.get_domains_with_instance_auth',
                                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccount': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccount',
                                                                                                                                  'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccount.__init__': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccount.__init__',
                                                                                                                                           'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccountProperty': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccountproperty',
                                                                                                                                          'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccountProperty.__init__': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccountproperty.__init__',
                                                                                                                                                   'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountNameError': ( 'integrations/domojupyter.html#invalidaccountnameerror',
                                                                                                                        'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountNameError.__init__': ( 'integrations/domojupyter.html#invalidaccountnameerror.__init__',
                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountTypeError': ( 'integrations/domojupyter.html#invalidaccounttypeerror',
                                                                                                                        'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountTypeError.__init__': ( 'integrations/domojupyter.html#invalidaccounttypeerror.__init__',
                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.NoConfigCompanyError': ( 'integrations/domojupyter.html#noconfigcompanyerror',
                                                                                                                     'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.NoConfigCompanyError.__init__': ( 'integrations/domojupyter.html#noconfigcompanyerror.__init__',
                                                                                                                              'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.get_jupyter_account': ( 'integrations/domojupyter.html#get_jupyter_account',
                                                                                                                    'domolibrary/integrations/DomoJupyter.py')},
            'domolibrary.routes.account': { 'domolibrary.routes.account.AccountConfig_InvalidDataProvider': ( 'routes/account.html#accountconfig_invaliddataprovider',
                                                                                                              'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.AccountConfig_InvalidDataProvider.__init__': ( 'routes/account.html#accountconfig_invaliddataprovider.__init__',
                                                                                                                       'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.create_account': ( 'routes/account.html#create_account',
                                                                                           'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.delete_account': ( 'routes/account.html#delete_account',
                                                                                           'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.get_account_config': ( 'routes/account.html#get_account_config',
                                                                                               'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.get_account_from_id': ( 'routes/account.html#get_account_from_id',
                                                                                                'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.get_accounts': ( 'routes/account.html#get_accounts',
                                                                                         'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.update_account_config': ( 'routes/account.html#update_account_config',
                                                                                                  'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.update_account_name': ( 'routes/account.html#update_account_name',
                                                                                                'domolibrary/routes/account.py')},
            'domolibrary.routes.activity_log': { 'domolibrary.routes.activity_log.get_activity_log_object_types': ( 'routes/activity_log.html#get_activity_log_object_types',
                                                                                                                    'domolibrary/routes/activity_log.py'),
                                                 'domolibrary.routes.activity_log.search_activity_log': ( 'routes/activity_log.html#search_activity_log',
                                                                                                          'domolibrary/routes/activity_log.py')},
            'domolibrary.routes.bootstrap': { 'domolibrary.routes.bootstrap.GetBootstrap_InvalidAuthMethod': ( 'routes/bootstrap.html#getbootstrap_invalidauthmethod',
                                                                                                               'domolibrary/routes/bootstrap.py'),
                                              'domolibrary.routes.bootstrap.GetBootstrap_InvalidAuthMethod.__init__': ( 'routes/bootstrap.html#getbootstrap_invalidauthmethod.__init__',
                                                                                                                        'domolibrary/routes/bootstrap.py'),
                                              'domolibrary.routes.bootstrap.get_bootstrap': ( 'routes/bootstrap.html#get_bootstrap',
                                                                                              'domolibrary/routes/bootstrap.py'),
                                              'domolibrary.routes.bootstrap.get_bootstrap_features': ( 'routes/bootstrap.html#get_bootstrap_features',
                                                                                                       'domolibrary/routes/bootstrap.py'),
                                              'domolibrary.routes.bootstrap.get_bootstrap_pages': ( 'routes/bootstrap.html#get_bootstrap_pages',
                                                                                                    'domolibrary/routes/bootstrap.py')},
            'domolibrary.routes.dataset': { 'domolibrary.routes.dataset.DatasetNotFoundError': ( 'routes/dataset.html#datasetnotfounderror',
                                                                                                 'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.DatasetNotFoundError.__init__': ( 'routes/dataset.html#datasetnotfounderror.__init__',
                                                                                                          'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.QueryRequestError': ( 'routes/dataset.html#queryrequesterror',
                                                                                              'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.QueryRequestError.__init__': ( 'routes/dataset.html#queryrequesterror.__init__',
                                                                                                       'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.UploadDataError': ( 'routes/dataset.html#uploaddataerror',
                                                                                            'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.UploadDataError.__init__': ( 'routes/dataset.html#uploaddataerror.__init__',
                                                                                                     'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.create': ( 'routes/dataset.html#create',
                                                                                   'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.generate_create_dataset_body': ( 'routes/dataset.html#generate_create_dataset_body',
                                                                                                         'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.generate_list_partitions_body': ( 'routes/dataset.html#generate_list_partitions_body',
                                                                                                          'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.get_dataset_by_id': ( 'routes/dataset.html#get_dataset_by_id',
                                                                                              'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.get_schema': ( 'routes/dataset.html#get_schema',
                                                                                       'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.index_dataset': ( 'routes/dataset.html#index_dataset',
                                                                                          'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.index_status': ( 'routes/dataset.html#index_status',
                                                                                         'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.list_partitions': ( 'routes/dataset.html#list_partitions',
                                                                                            'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.query_dataset_private': ( 'routes/dataset.html#query_dataset_private',
                                                                                                  'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.query_dataset_public': ( 'routes/dataset.html#query_dataset_public',
                                                                                                 'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.set_dataset_tags': ( 'routes/dataset.html#set_dataset_tags',
                                                                                             'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_1': ( 'routes/dataset.html#upload_dataset_stage_1',
                                                                                                   'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_2_df': ( 'routes/dataset.html#upload_dataset_stage_2_df',
                                                                                                      'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_2_file': ( 'routes/dataset.html#upload_dataset_stage_2_file',
                                                                                                        'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_3': ( 'routes/dataset.html#upload_dataset_stage_3',
                                                                                                   'domolibrary/routes/dataset.py')},
            'domolibrary.routes.user': { 'domolibrary.routes.user.create_user': ( 'routes/user.html#create_user',
                                                                                  'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.generate_search_users_body_by_email': ( 'routes/user.html#generate_search_users_body_by_email',
                                                                                                          'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.generate_search_users_body_by_id': ( 'routes/user.html#generate_search_users_body_by_id',
                                                                                                       'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.get_all_users': ( 'routes/user.html#get_all_users',
                                                                                    'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.process_v1_search_users': ( 'routes/user.html#process_v1_search_users',
                                                                                              'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.request_password_reset': ( 'routes/user.html#request_password_reset',
                                                                                             'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.reset_password': ( 'routes/user.html#reset_password',
                                                                                     'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.search_users': ( 'routes/user.html#search_users',
                                                                                   'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.search_virtual_user_by_subscriber_instance': ( 'routes/user.html#search_virtual_user_by_subscriber_instance',
                                                                                                                 'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.set_user_landing_page': ( 'routes/user.html#set_user_landing_page',
                                                                                            'domolibrary/routes/user.py')},
            'domolibrary.utils.DictDot': { 'domolibrary.utils.DictDot.DictDot': ( 'utils/dictdot.html#dictdot',
                                                                                  'domolibrary/utils/DictDot.py'),
                                           'domolibrary.utils.DictDot.DictDot.__getattr__': ( 'utils/dictdot.html#dictdot.__getattr__',
                                                                                              'domolibrary/utils/DictDot.py'),
                                           'domolibrary.utils.DictDot.DictDot.__init__': ( 'utils/dictdot.html#dictdot.__init__',
                                                                                           'domolibrary/utils/DictDot.py')},
            'domolibrary.utils.convert': { 'domolibrary.utils.convert.convert_datetime_to_epoch_millisecond': ( 'utils/convert.html#convert_datetime_to_epoch_millisecond',
                                                                                                                'domolibrary/utils/convert.py'),
                                           'domolibrary.utils.convert.convert_epoch_millisecond_to_datetime': ( 'utils/convert.html#convert_epoch_millisecond_to_datetime',
                                                                                                                'domolibrary/utils/convert.py'),
                                           'domolibrary.utils.convert.convert_snake_to_pascal': ( 'utils/convert.html#convert_snake_to_pascal',
                                                                                                  'domolibrary/utils/convert.py')}}}
